@@ -54,7 +54,8 @@ static inline void free_thread(dbm_solver_thread *const thread)
 
 // Returns whether the process should terminate.
 static bool handle_and_destroy_instance_solution(
-    dbm_solver_instance *const instance, fcs_delta_stater *const delta)
+    dbm_solver_instance *const instance,
+    fcs_delta_stater *const delta GCC_UNUSED)
 {
     FILE *const out_fh = instance->common.out_fh;
     bool ret = false;
@@ -62,7 +63,9 @@ static bool handle_and_destroy_instance_solution(
     instance_print_stats(instance);
     if (instance->common.queue_solution_was_found)
     {
+#ifndef FCS_DBM__VAL_IS_ANCESTOR
         trace_solution(instance, out_fh, delta);
+#endif
         ret = true;
     }
     else if (instance->common.should_terminate != DONT_TERMINATE)
