@@ -56,7 +56,7 @@ static inline void sort_derived_states(
     for (var_AUTO(b, start + 1); b < limit; b++)
     {
         for (var_AUTO(c, b); (c > start) && (c[0].context.i < c[-1].context.i);
-             c--)
+            c--)
         {
             const_AUTO(swap_temp, c[-1]);
             c[-1] = c[0];
@@ -551,7 +551,7 @@ static inline void col_seqs_iter__calc_end(col_seqs_iter *const iter)
     FCS_ON_NOT_FC_ONLY(const_SLOT(sequences_are_built_by, iter));
     const_SLOT(col, iter);
     for ((*iter).seq_end = (*iter).c; (*iter).seq_end < (*iter).col_len_minus_1;
-         ++((*iter).seq_end))
+        ++((*iter).seq_end))
     {
         if (!fcs_is_parent_card(fcs_col_get_card(col, (*iter).seq_end + 1),
                 fcs_col_get_card(col, (*iter).seq_end)))
@@ -995,7 +995,7 @@ DECLARE_MOVE_FUNCTION(fc_solve_sfs_move_cards_to_a_different_parent)
         int min_card_height;
         fcs_card lower_card;
         for (min_card_height = cards_num - 2; min_card_height >= 0;
-             upper_card = lower_card, --min_card_height)
+            upper_card = lower_card, --min_card_height)
         {
             lower_card = fcs_col_get_card(col, min_card_height);
             if (!fcs_is_parent_card(upper_card, lower_card))
@@ -1435,6 +1435,54 @@ extern fcs_collectible_state *fc_solve_sfs_raymond_prune(
         }
     } while (num_cards_moved);
 
+    /*
+     * Enable a prune that makes bulk / range benchnmarks run faster
+     * but breaks the test suite and makes some deals unsolved.
+     *
+     * Currently requires patching the source.
+     * */
+#define ENABLE_ONE_CARD_COLUMNS_PRUNE 0
+#if ENABLE_ONE_CARD_COLUMNS_PRUNE
+    int next_fc = 0;
+
+    for (stack_i stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
+    {
+        const_AUTO(col, fcs_state_get_col(new_state_key, stack_idx));
+        const int cards_num = fcs_col_len(col);
+
+        if (1 != cards_num)
+        {
+            continue;
+        }
+        const fcs_card card = fcs_col_get_card(col, 0);
+        while (next_fc < LOCAL_FREECELLS_NUM)
+        {
+            if (!fcs_freecell_is_empty(new_state_key, next_fc))
+            {
+                ++next_fc;
+            }
+            else
+            {
+                break;
+            }
+        }
+        if (next_fc >= LOCAL_FREECELLS_NUM)
+        {
+            break;
+        }
+
+        num_cards_moved = true;
+        cards_were_moved = true;
+
+        my_copy_stack(stack_idx);
+        fcs_state_pop_col_top(&new_state_key, stack_idx);
+        fcs_put_card_in_freecell(new_state_key, next_fc, card);
+        fcs_move_stack_non_seq_push(moves, FCS_MOVE_TYPE_STACK_TO_FREECELL,
+            stack_idx, (stack_i)next_fc);
+        ++next_fc;
+    }
+#endif
+
     if (!cards_were_moved)
     {
         return NULL;
