@@ -1,16 +1,18 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
 // generic_tree.h - provide a unified interface to either kaz_tree.h
 // or fcs-libavl/rb.h .
 #pragma once
-#include "fcs_conf.h"
+#include "freecell-solver/fcs_conf.h"
+
+#ifdef FCS_DBM_USE_HASH
+#include "dbm_hashtable.h"
+#else
 
 #ifdef FCS_DBM_USE_LIBAVL
 
@@ -35,3 +37,4 @@ static inline void fc_solve_kaz_tree_delete_by_value(
 }
 
 #endif
+#endif
