@@ -133,7 +133,8 @@ typedef struct dict_load_t
 #ifdef NO_FC_SOLVE
 extern dict_t *dict_create(dictcount_t, dict_comp_t, void *);
 #else
-extern dict_t *fc_solve_kaz_tree_create(dict_comp_t, void *, meta_allocator *);
+extern dict_t *fc_solve_kaz_tree_create(
+    dict_comp_t, void *, meta_allocator *, void *);
 #endif
 #if 0
 extern void dict_set_allocator(dict_t *, dnode_alloc_t, dnode_free_t, void *);
