@@ -5,11 +5,11 @@ use strict;
 use warnings;
 use autodie;
 
-use Getopt::Long qw/ GetOptions /;
-use Env::Path ();
-use Path::Tiny qw/ path /;
+use Getopt::Long   qw/ GetOptions /;
+use Env::Path      ();
+use Path::Tiny     qw/ path /;
 use File::Basename qw/ basename /;
-use CHI ();
+use CHI            ();
 
 my $glob_was_set = 0;
 my $rerun        = 0;
@@ -113,25 +113,33 @@ if ( $FC_Solve::Paths::Base::IS_WIN || $force_rebuild )
 }
 else
 {
-    foreach my $prog ( keys %progs )
+    eval {
+        foreach my $prog ( keys %progs )
+        {
+            say $prog;
+            die if !-e $prog;
+            foreach my $bin ( $prog, `ldd "$prog"` =~ m# => (\S+)#g )
+            {
+                say "bin $prog $bin";
+                $progs{$prog}{binaries}{$bin} //= (
+                    $binaries{$bin} //= do
+                    {
+                        Digest->new('SHA-256')->addfile($bin)->b64digest;
+                    }
+                );
+            }
+            my $val = $cache->get( $progs{$prog} );
+            if ( !$val )
+            {
+                ++$rerun;
+            }
+        }
+
+    };
+    if ( my $Err = $@ )
     {
-        say $prog;
-        die if !-e $prog;
-        foreach my $bin ( $prog, `ldd "$prog"` =~ m# => (\S+)#g )
-        {
-            say "bin $prog $bin";
-            $progs{$prog}{binaries}{$bin} //= (
-                $binaries{$bin} //= do
-                {
-                    Digest->new('SHA-256')->addfile($bin)->b64digest;
-                }
-            );
-        }
-        my $val = $cache->get( $progs{$prog} );
-        if ( !$val )
-        {
-            ++$rerun;
-        }
+        warn $Err;
+        ++$rerun;
     }
 }
 $glob_was_set ||= $exclude_re_s;
@@ -207,6 +215,8 @@ sub myglob
 
     Env::Path->CPATH->Prepend( $abs_bindir, );
 
+    $ENV{'LD_LIBRARY_PATH__ORIG'} =
+        ( $ENV{'LD_LIBRARY_PATH'} // "" );
     Env::Path->LD_LIBRARY_PATH->Prepend($fcs_bin_path);
     if ($FC_Solve::Paths::Base::IS_WIN)
     {
