@@ -5,8 +5,8 @@ use warnings;
 
 use parent 'Games::Solitaire::Verify::Base';
 
-use YAML::XS qw(DumpFile LoadFile);
-use FC_Solve::Paths qw( is_freecell_only is_without_flares );
+use YAML::XS        qw(DumpFile LoadFile);
+use FC_Solve::Paths qw( is_freecell_only is_tag is_without_flares );
 
 use Carp ();
 
@@ -78,6 +78,11 @@ q#Test skipped because it uses flares, and we are running on a build without fla
         );
     }
 
+    if ( $args->{visited_iter} and is_tag('FCS_WITHOUT_VISITED_ITER') )
+    {
+        return ok( 1, q#Test skipped because it needs visited-iter.# );
+    }
+
     my $id = $args->{id};
     if ( !$id )
     {
@@ -137,7 +142,6 @@ q#Test skipped because it uses flares, and we are running on a build without fla
                 }
                 substr( $$s, $pos + $TRIM_NEEDLE_LEN ) = '';
             }
-            $$s =~ s/ +(\n)/$1/g;
             return $s;
         }
     );
