@@ -23,7 +23,7 @@ __PACKAGE__->populate(
     [
         '1_sp' => {
             args => { deal => 1, theme => [ "--set-pruning", "r:tf", ], },
-            msg => "Solving Deal #1 with set-pruning run-to-founds",
+            msg  => "Solving Deal #1 with set-pruning run-to-founds",
         },
         '1_sp_a_star' => {
             args => {
@@ -42,11 +42,11 @@ __PACKAGE__->populate(
         },
         '24_default' => {
             args => { deal => 24, theme => [], },
-            msg => "Solving Deal #24 with the default heuristic",
+            msg  => "Solving Deal #24 with the default heuristic",
         },
         '24_sp' => {
             args => { deal => 24, theme => [ "--set-pruning", "r:tf", ], },
-            msg => "Solving Deal #24 with set-pruning run-to-founds",
+            msg  => "Solving Deal #24 with set-pruning run-to-founds",
         },
         '110_dto2' => {
             args => {
@@ -62,23 +62,27 @@ __PACKAGE__->populate(
         },
         '617_jgl' => {
             args => { deal => 617, theme => [ "-l", "john-galt-line" ], },
-            msg => "Solving Deal #617 with the john-galt-line",
+            msg  => "Solving Deal #617 with the john-galt-line",
         },
         '24_bakers_game' => {
             args => { deal => 24, variant => "bakers_game", theme => [], },
-            msg => "Baker's Game Deal #24"
+            msg  => "Baker's Game Deal #24"
+        },
+        '17_lg' => {
+            args => { deal => 17, theme => [ "-l", "looking-glass", ], },
+            msg  => "Freecell Deal No. 17 with the lg preset",
         },
         '1941_as' => {
             args => { deal => 1941, theme => [ "-l", "amateur-star", ], },
-            msg => "Freecell Dal No. 1941 with the amateur-star preset",
+            msg  => "Freecell Deal No. 1941 with the amateur-star preset",
         },
         '1099_forecell' => {
             args => { deal => 1099, variant => "forecell", theme => [], },
-            msg => "Forecell Deal #1099",
+            msg  => "Forecell Deal #1099",
         },
         '11982_relaxed' => {
             args => { deal => 11982, variant => "relaxed_freecell", },
-            msg => "Relaxed Freecell Deal #11982",
+            msg  => "Relaxed Freecell Deal #11982",
         },
         '1977_seahaven' => {
             args => {
@@ -97,7 +101,7 @@ __PACKAGE__->populate(
         },
         '200_eight_off_default' => {
             args => { deal => 200, variant => "eight_off", theme => [], },
-            msg => "Eight Off #200 with default heuristic",
+            msg  => "Eight Off #200 with default heuristic",
         },
         '24_ct' => {
             args => { deal => 24, theme => [ '-l', 'ct', ], },
@@ -109,15 +113,15 @@ __PACKAGE__->populate(
         },
         '24_opt_sp_r_tf' => {
             args => { deal => 24, theme => [ "-opt", "-sp", "r:tf", ], },
-            msg => "-opt in conjunction with --set-pruning r:tf should work.",
+            msg  => "-opt in conjunction with --set-pruning r:tf should work.",
         },
         '24_simple_simon__default' => {
             args => { deal => 24, variant => "simple_simon", theme => [], },
-            msg => "Simple Simon #24 with default theme",
+            msg  => "Simple Simon #24 with default theme",
         },
         '246_eo' => {
             args => { deal => 246, theme => [ "-l", "eo" ], },
-            msg => "Solving Deal #246 with the enlightened-ostrich",
+            msg  => "Solving Deal #246 with the enlightened-ostrich",
         },
 
         # This command line theme yields an especially short solution to the
@@ -165,7 +169,7 @@ __PACKAGE__->populate(
         },
         '19806_simple_simon__default' => {
             args => { deal => 19806, variant => "simple_simon", theme => [], },
-            msg => "Simple Simon #19806 with default theme",
+            msg  => "Simple Simon #19806 with default theme",
         },
         '1_simple_simon__abcdefghi' => {
             args => {
